@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2013, 2014, 2015, 2017 Graeme Gott <graeme@gottcode.org>
+ * Copyright (C) 2013, 2014, 2015, 2016, 2017 Graeme Gott <graeme@gottcode.org>
  *
  * This library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -197,7 +197,6 @@ gboolean Page::view_popup_menu_event(GtkWidget* view)
 
 void Page::create_context_menu(GtkTreeIter* iter, GdkEvent* event)
 {
-	GdkEventButton* event_button = reinterpret_cast<GdkEventButton*>(event);
 	m_selected_path = gtk_tree_model_get_path(m_view->get_model(), iter);
 	Launcher* launcher = get_selected_launcher();
 	if (!launcher)
@@ -223,9 +222,11 @@ void Page::create_context_menu(GtkTreeIter* iter, GdkEvent* event)
 		for (std::vector<DesktopAction*>::size_type i = 0, end = actions.size(); i < end; ++i)
 		{
 			DesktopAction* action = actions[i];
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 			menuitem = gtk_image_menu_item_new_with_label(action->get_name());
 			GtkWidget* image = gtk_image_new_from_icon_name(action->get_icon(), GTK_ICON_SIZE_MENU);
 			gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menuitem), image);
+G_GNUC_END_IGNORE_DEPRECATIONS
 			g_signal_connect_slot(menuitem, "activate", &Page::item_action_activated, this, action);
 			gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
 		}
@@ -234,6 +235,7 @@ void Page::create_context_menu(GtkTreeIter* iter, GdkEvent* event)
 		gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
 	}
 
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
 	if (!m_window->get_favorites()->contains(launcher))
 	{
 		menuitem = gtk_image_menu_item_new_with_label(_("Add to Favorites"));
@@ -250,6 +252,7 @@ void Page::create_context_menu(GtkTreeIter* iter, GdkEvent* event)
 		g_signal_connect_slot<GtkMenuItem*>(menuitem, "activate", &Page::remove_selected_from_favorites, this);
 		gtk_menu_shell_append(GTK_MENU_SHELL(menu), menuitem);
 	}
+G_GNUC_END_IGNORE_DEPRECATIONS
 
 	menuitem = gtk_menu_item_new_with_label(_("Add to Desktop"));
 	g_signal_connect_slot<GtkMenuItem*>(menuitem, "activate", &Page::add_selected_to_desktop, this);
@@ -271,11 +274,17 @@ void Page::create_context_menu(GtkTreeIter* iter, GdkEvent* event)
 	gtk_widget_show_all(menu);
 
 	// Show context menu
+	gtk_tree_view_set_hover_selection(GTK_TREE_VIEW(m_view->get_widget()), false);
+	gtk_menu_attach_to_widget(GTK_MENU(menu), m_view->get_widget(), NULL);
+#if GTK_CHECK_VERSION(3,22,0)
+	gtk_menu_popup_at_pointer(GTK_MENU(menu), event);
+#else
 	int button = 0;
 	int event_time;
 	GtkMenuPositionFunc position_func = NULL;
 	if (event)
 	{
+		GdkEventButton* event_button = reinterpret_cast<GdkEventButton*>(event);
 		button = event_button->button;
 		event_time = event_button->time;
 	}
@@ -285,9 +294,8 @@ void Page::create_context_menu(GtkTreeIter* iter, GdkEvent* event)
 		event_time = gtk_get_current_event_time ();
 	}
 
-	gtk_tree_view_set_hover_selection(GTK_TREE_VIEW(m_view->get_widget()), false);
-	gtk_menu_attach_to_widget(GTK_MENU(menu), m_view->get_widget(), NULL);
 	gtk_menu_popup(GTK_MENU(menu), NULL, NULL, position_func, this, button, event_time);
+#endif
 }
 
 //-----------------------------------------------------------------------------
